#ifndef GAP_BUILD_VERSION
#define GAP_BUILD_VERSION  "4.8.7, 24-Mar-2017, build"
#define GAP_BUILD_DATETIME "2017-06-20 05:52:19 (UTC)"
#endif
